@@ -1,4 +1,10 @@
-def _convert_to_frontmatter(content): # TODO: Move this to a helper script.
+# Frontmatter Helpers
+# IDEAS:
+#   - Create New Content Template
+#   - Preview Frontmatter to HTML
+
+
+def _convert_to_frontmatter(content):
     """if not formatted for frontmatter, add lines"""
     if not content.startswith("---"):
         content = f"---\n{content}"
